# WebExtensions, web_accessible_resources, .javascript, and macOS file associations issue

## Overview

It sounds strange, but loading a `.javascript` file from a WebExtension's [web_accessible_resources](https://developer.mozilla.org/en-US/Add-ons/WebExtensions/manifest.json/web_accessible_resources) somehow causes problems with the macOS file associations, most notable so with TextMate 2.

This Gist contains a simple Web Extension and instructions to reproduce the issue.

[A screen recording demonstrating the issue can be seen here](https://www.youtube.com/watch?v=VNKD40UspzM).


## Tested On

-   macOS 10.13.3 (native and in a clean VM)
-   Firefox 59.0.1 (Stable)
-   Firefox 60.0b5 (Developer Edition)
-   Several previous Firefox versions


## Reproduce Instructions

1.  Download this Gist if you have not already.
2.  Install [TextMate 2 RC 8](https://github.com/textmate/textmate/releases/download/v2.0-rc.8/TextMate_2.0-rc.8.tbz) (exact version probably does not matter).
3.  In Finder navigate to the Gist, select `file.js` and `file.txt`, click File > Get Info, and set all of them to open with TextMate, making sure to click "Change All" for each one.
4.  Make sure TextMate is not running, then open Firefox 59.0.1 (exact version probably does not matter), ideally with a new profile.
5.  Go to `about:debugging`, click "Load Temporary Add-On" and open the `manifest.json` file in this Gist.
6.  Verify in Finder that TextMate is still the default editor for `.js`, and `.txt` files.
7.  Go to a page that loads `google-analytics.com/analytics.js`, like [this minimal one](https://cdn.rawgit.com/AlexanderOMara/485d4a794eb861dc36745a85503edea2/raw/523fe64b31abb33fb844bd39b771dd51b7f7d3f8/index.html).
8.  In Finder, select `file.js`, and `file.txt` again and click File > Get Info and see that it has changed (you can also try opening them to confirm it has changed).
9.  Open TextMate.
10. Repeat step 8 to see it has actually changed back.
11. Reload the page from step 7 to see it change again.


## Notes

-   You can simply refresh the page to see the issue repeat.
-   You can edit `background.js` to load `war-test.js` instead of `war-test.javascript` and see the issue no longer happens.
-   Other extensions do not seem to cause the problem, it seems something is special about the `.javascript` extension.
-   If the `moz-extension://` URL is known and added to the DOM, it is possible to trigger the issue without a `onBeforeRequest` redirect.
-   Requests to `.javascript` files outside of `web_accessible_resources` does not cause an issue.
-   Current versions of uBlock Origin (1.15.12+, since [this commit](https://github.com/gorhill/uBlock/commit/17930cc778c20e11fd4c760d710e8ba619aab666)) also causes this issue.
